@@ -24,16 +24,13 @@ class Crawling(LibraryComponent):
 
         returns list of crawled urls.
 
-        ``url`` is the page to start crawling from.
+        | =Arguments= | =Description= |
+        | ``url`` | is the page to start crawling from. |
+        | ``page_crawl_keyword`` | is the keyword that will be executed on every page.  By default it will take a screenshot on every page. |
+        | ``max_number_of_page_to_crawl`` | is the upper limit of pages to crawl. Crawling will stop if the number of crawled pages goes over this. |
+        | ``max_depth_to_crawl`` | is the upper limit of consecutive links followed from the start page. Crawling will stop if there are no more links under this depth. |
 
-        ``page_crawl_keyword`` is the keyword that will be executed on every page.
-        By default it will take a screenshot on every page.
-
-        ``max_number_of_page_to_crawl`` is the upper limit of pages to crawl.
-        Crawling will stop if the number of crawled pages goes over this.
-
-        ``max_depth_to_crawl`` is the upper limit of consecutive links followed from the start page.
-        Crawling will stop if there are no more links under this depth.
+        [https://forum.robotframework.org/t//4243|Comment >>]
         """
         if url:
             self.library.new_page(url)
